==> haskell-multistate-0.8.0.4-174-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-multistate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 multistate
version:              0.8.0.4
visibility:           public
id:                   multistate-0.8.0.4-OtloMp5beAoKDG0pPXpu
key:                  multistate-0.8.0.4-OtloMp5beAoKDG0pPXpu
license:              BSD-3-Clause
copyright:            Copyright (C) 2013 Jan Bracker, 2013-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Jan Bracker, Lennart Spitzner
stability:            Experimental
homepage:             https://github.com/lspitzner/multistate
synopsis:
    like mtl'\''s ReaderT / WriterT / StateT, but more than one
    contained value/type.

description:
    When using multiple Read\/Write\/State transformers in the same monad stack,
    it becomes necessary to lift the operations in order to affect a specific
    transformer.
    Using heterogeneous lists (and all kinds of GHC extensions magic),
    this package provides transformers that remove that necessity:
    MultiReaderT\/MultiWriterT\/MultiStateT\/MultiRWST can contain a
    heterogeneous list of values.

    See the <https://github.com/lspitzner/multistate README> for
    a longer description.

category:             Control
abi:                  a39a065f44420d5f127160756984ef9f
exposed:              True
exposed-modules:
    Control.Monad.Trans.MultiGST Control.Monad.Trans.MultiGST.Lazy
    Control.Monad.Trans.MultiGST.Strict
    Control.Monad.Trans.MultiGet.Class Control.Monad.Trans.MultiRWS
    Control.Monad.Trans.MultiRWS.Lazy
    Control.Monad.Trans.MultiRWS.Strict Control.Monad.Trans.MultiReader
    Control.Monad.Trans.MultiReader.Class
    Control.Monad.Trans.MultiReader.Lazy
    Control.Monad.Trans.MultiReader.Strict
    Control.Monad.Trans.MultiState Control.Monad.Trans.MultiState.Class
    Control.Monad.Trans.MultiState.Lazy
    Control.Monad.Trans.MultiState.Strict
    Control.Monad.Trans.MultiWriter
    Control.Monad.Trans.MultiWriter.Class
    Control.Monad.Trans.MultiWriter.Lazy
    Control.Monad.Trans.MultiWriter.Strict Data.HList.ContainsType
    Data.HList.HList

hidden-modules:       Control.Monad.Trans.MultiGST.Common
import-dirs:          /usr/lib/ghc-9.4.8/site-local/multistate-0.8.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/multistate-0.8.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/multistate-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-multistate
hs-libraries:         HSmultistate-0.8.0.4-OtloMp5beAoKDG0pPXpu
depends:
    base-4.17.2.1 monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs
    mtl-2.2.2 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA

haddock-interfaces:   /usr/share/doc/haskell-multistate/html/multistate.haddock
haddock-html:         /usr/share/doc/haskell-multistate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-multistate-0.8.0.4-179-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-multistate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 multistate
version:              0.8.0.4
visibility:           public
id:                   multistate-0.8.0.4-HlF6eDi01EWIWQ3ClG9cqX
key:                  multistate-0.8.0.4-HlF6eDi01EWIWQ3ClG9cqX
license:              BSD-3-Clause
copyright:            Copyright (C) 2013 Jan Bracker, 2013-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Jan Bracker, Lennart Spitzner
stability:            Experimental
homepage:             https://github.com/lspitzner/multistate
synopsis:
    like mtl'\''s ReaderT / WriterT / StateT, but more than one
    contained value/type.

description:
    When using multiple Read\/Write\/State transformers in the same monad stack,
    it becomes necessary to lift the operations in order to affect a specific
    transformer.
    Using heterogeneous lists (and all kinds of GHC extensions magic),
    this package provides transformers that remove that necessity:
    MultiReaderT\/MultiWriterT\/MultiStateT\/MultiRWST can contain a
    heterogeneous list of values.

    See the <https://github.com/lspitzner/multistate README> for
    a longer description.

category:             Control
abi:                  423ee4e1e3fc87ea60d7e7037ca79f60
exposed:              True
exposed-modules:
    Control.Monad.Trans.MultiGST Control.Monad.Trans.MultiGST.Lazy
    Control.Monad.Trans.MultiGST.Strict
    Control.Monad.Trans.MultiGet.Class Control.Monad.Trans.MultiRWS
    Control.Monad.Trans.MultiRWS.Lazy
    Control.Monad.Trans.MultiRWS.Strict Control.Monad.Trans.MultiReader
    Control.Monad.Trans.MultiReader.Class
    Control.Monad.Trans.MultiReader.Lazy
    Control.Monad.Trans.MultiReader.Strict
    Control.Monad.Trans.MultiState Control.Monad.Trans.MultiState.Class
    Control.Monad.Trans.MultiState.Lazy
    Control.Monad.Trans.MultiState.Strict
    Control.Monad.Trans.MultiWriter
    Control.Monad.Trans.MultiWriter.Class
    Control.Monad.Trans.MultiWriter.Lazy
    Control.Monad.Trans.MultiWriter.Strict Data.HList.ContainsType
    Data.HList.HList

hidden-modules:       Control.Monad.Trans.MultiGST.Common
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/multistate-0.8.0.4
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/multistate-0.8.0.4
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/multistate-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-multistate
hs-libraries:         HSmultistate-0.8.0.4-HlF6eDi01EWIWQ3ClG9cqX
depends:
    base-4.18.3.0 monad-control-1.0.3.1-FK5MwN7CLMeDFbgWPeqycv
    mtl-2.3.1 tagged-0.8.9-HMh4qZxoofeBZ9IcdInbXO transformers-0.6.1.0
    transformers-base-0.4.6-KecQozQ2bJs3HLDcaEYSEy

haddock-interfaces:   /usr/share/doc/haskell-multistate/html/multistate.haddock
haddock-html:         /usr/share/doc/haskell-multistate/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
